@@ -1,16 +1,15 @@
-# Copyright (c) 2019-2020 hippo91 <guillaume.peillex@gmail.com>
-# Copyright (c) 2020 Claudiu Popa <pcmanticore@gmail.com>
-
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/master/COPYING.LESSER
-
+# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
 
 """Astroid hooks for numpy.core.function_base module."""
 
 import functools
-import astroid
-from brain_numpy_utils import looks_like_numpy_member, infer_numpy_member
 
+from astroid.brain.brain_numpy_utils import infer_numpy_member, looks_like_numpy_member
+from astroid.inference_tip import inference_tip
+from astroid.manager import AstroidManager
+from astroid.nodes.node_classes import Attribute
 
 METHODS_TO_BE_INFERRED = {
     "linspace": """def linspace(start, stop, num=50, endpoint=True, retstep=False, dtype=None, axis=0):
@@ -23,8 +22,8 @@ METHODS_TO_BE_INFERRED = {
 
 for func_name, func_src in METHODS_TO_BE_INFERRED.items():
     inference_function = functools.partial(infer_numpy_member, func_src)
-    astroid.MANAGER.register_transform(
-        astroid.Attribute,
-        astroid.inference_tip(inference_function),
+    AstroidManager().register_transform(
+        Attribute,
+        inference_tip(inference_function),
         functools.partial(looks_like_numpy_member, func_name),
     )
